==> kubernetes-model-admissionregistration-6.1.1-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SelfSubjectAccessReviewFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SelfSubjectAccessReviewFluentImpl<A extends SelfSubjectAccessReviewFluent<A>> extends BaseFluent<A> implements SelfSubjectAccessReviewFluent<A>{
  public SelfSubjectAccessReviewFluentImpl() {
  }
  public SelfSubjectAccessReviewFluentImpl(SelfSubjectAccessReview instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private SelfSubjectAccessReviewSpecBuilder spec;
  private SubjectAccessReviewStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public SelfSubjectAccessReviewFluent.MetadataNested<A> withNewMetadata() {
    return new SelfSubjectAccessReviewFluentImpl.MetadataNestedImpl();
  }
  public SelfSubjectAccessReviewFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new SelfSubjectAccessReviewFluentImpl.MetadataNestedImpl(item);
  }
  public SelfSubjectAccessReviewFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public SelfSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public SelfSubjectAccessReviewFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SelfSubjectAccessReviewSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public SelfSubjectAccessReviewSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(SelfSubjectAccessReviewSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new SelfSubjectAccessReviewSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public SelfSubjectAccessReviewFluent.SpecNested<A> withNewSpec() {
    return new SelfSubjectAccessReviewFluentImpl.SpecNestedImpl();
  }
  public SelfSubjectAccessReviewFluent.SpecNested<A> withNewSpecLike(SelfSubjectAccessReviewSpec item) {
    return new SelfSubjectAccessReviewFluentImpl.SpecNestedImpl(item);
  }
  public SelfSubjectAccessReviewFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public SelfSubjectAccessReviewFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new SelfSubjectAccessReviewSpecBuilder().build());
  }
  public SelfSubjectAccessReviewFluent.SpecNested<A> editOrNewSpecLike(SelfSubjectAccessReviewSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubjectAccessReviewStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public SubjectAccessReviewStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(SubjectAccessReviewStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new SubjectAccessReviewStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Boolean allowed,Boolean denied,String evaluationError,String reason) {
    return (A)withStatus(new SubjectAccessReviewStatus(allowed, denied, evaluationError, reason));
  }
  public SelfSubjectAccessReviewFluent.StatusNested<A> withNewStatus() {
    return new SelfSubjectAccessReviewFluentImpl.StatusNestedImpl();
  }
  public SelfSubjectAccessReviewFluent.StatusNested<A> withNewStatusLike(SubjectAccessReviewStatus item) {
    return new SelfSubjectAccessReviewFluentImpl.StatusNestedImpl(item);
  }
  public SelfSubjectAccessReviewFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public SelfSubjectAccessReviewFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new SubjectAccessReviewStatusBuilder().build());
  }
  public SelfSubjectAccessReviewFluent.StatusNested<A> editOrNewStatusLike(SubjectAccessReviewStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SelfSubjectAccessReviewFluentImpl that = (SelfSubjectAccessReviewFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<SelfSubjectAccessReviewFluent.MetadataNested<N>> implements SelfSubjectAccessReviewFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) SelfSubjectAccessReviewFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends SelfSubjectAccessReviewSpecFluentImpl<SelfSubjectAccessReviewFluent.SpecNested<N>> implements SelfSubjectAccessReviewFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(SelfSubjectAccessReviewSpec item) {
      this.builder = new SelfSubjectAccessReviewSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new SelfSubjectAccessReviewSpecBuilder(this);
    }
    SelfSubjectAccessReviewSpecBuilder builder;
    public N and() {
      return (N) SelfSubjectAccessReviewFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends SubjectAccessReviewStatusFluentImpl<SelfSubjectAccessReviewFluent.StatusNested<N>> implements SelfSubjectAccessReviewFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(SubjectAccessReviewStatus item) {
      this.builder = new SubjectAccessReviewStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new SubjectAccessReviewStatusBuilder(this);
    }
    SubjectAccessReviewStatusBuilder builder;
    public N and() {
      return (N) SelfSubjectAccessReviewFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1beta1/SelfSubjectAccessReviewFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SelfSubjectAccessReviewFluentImpl<A extends SelfSubjectAccessReviewFluent<A>> extends BaseFluent<A> implements SelfSubjectAccessReviewFluent<A>{
  public SelfSubjectAccessReviewFluentImpl() {
  }
  public SelfSubjectAccessReviewFluentImpl(SelfSubjectAccessReview instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private SelfSubjectAccessReviewSpecBuilder spec;
  private SubjectAccessReviewStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public SelfSubjectAccessReviewFluentImpl.MetadataNested<A> withNewMetadata() {
    return new SelfSubjectAccessReviewFluentImpl.MetadataNestedImpl();
  }
  public SelfSubjectAccessReviewFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new SelfSubjectAccessReviewFluentImpl.MetadataNestedImpl(item);
  }
  public SelfSubjectAccessReviewFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public SelfSubjectAccessReviewFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public SelfSubjectAccessReviewFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public SelfSubjectAccessReviewSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public SelfSubjectAccessReviewSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(SelfSubjectAccessReviewSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new SelfSubjectAccessReviewSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public SelfSubjectAccessReviewFluentImpl.SpecNested<A> withNewSpec() {
    return new SelfSubjectAccessReviewFluentImpl.SpecNestedImpl();
  }
  public SelfSubjectAccessReviewFluentImpl.SpecNested<A> withNewSpecLike(SelfSubjectAccessReviewSpec item) {
    return new SelfSubjectAccessReviewFluentImpl.SpecNestedImpl(item);
  }
  public SelfSubjectAccessReviewFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public SelfSubjectAccessReviewFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new SelfSubjectAccessReviewSpecBuilder().build());
  }
  public SelfSubjectAccessReviewFluentImpl.SpecNested<A> editOrNewSpecLike(SelfSubjectAccessReviewSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public SubjectAccessReviewStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public SubjectAccessReviewStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(SubjectAccessReviewStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new SubjectAccessReviewStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public A withNewStatus(Boolean allowed,Boolean denied,String evaluationError,String reason) {
    return (A)withStatus(new SubjectAccessReviewStatus(allowed, denied, evaluationError, reason));
  }
  public SelfSubjectAccessReviewFluentImpl.StatusNested<A> withNewStatus() {
    return new SelfSubjectAccessReviewFluentImpl.StatusNestedImpl();
  }
  public SelfSubjectAccessReviewFluentImpl.StatusNested<A> withNewStatusLike(SubjectAccessReviewStatus item) {
    return new SelfSubjectAccessReviewFluentImpl.StatusNestedImpl(item);
  }
  public SelfSubjectAccessReviewFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public SelfSubjectAccessReviewFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new SubjectAccessReviewStatusBuilder().build());
  }
  public SelfSubjectAccessReviewFluentImpl.StatusNested<A> editOrNewStatusLike(SubjectAccessReviewStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SelfSubjectAccessReviewFluentImpl that = (SelfSubjectAccessReviewFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<SelfSubjectAccessReviewFluentImpl.MetadataNested<N>> implements SelfSubjectAccessReviewFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) SelfSubjectAccessReviewFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends SelfSubjectAccessReviewSpecFluentImpl<SelfSubjectAccessReviewFluentImpl.SpecNested<N>> implements SelfSubjectAccessReviewFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(SelfSubjectAccessReviewSpec item) {
      this.builder = new SelfSubjectAccessReviewSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new SelfSubjectAccessReviewSpecBuilder(this);
    }
    SelfSubjectAccessReviewSpecBuilder builder;
    public N and() {
      return (N) SelfSubjectAccessReviewFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends SubjectAccessReviewStatusFluentImpl<SelfSubjectAccessReviewFluentImpl.StatusNested<N>> implements SelfSubjectAccessReviewFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(SubjectAccessReviewStatus item) {
      this.builder = new SubjectAccessReviewStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new SubjectAccessReviewStatusBuilder(this);
    }
    SubjectAccessReviewStatusBuilder builder;
    public N and() {
      return (N) SelfSubjectAccessReviewFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
